| Safe Haskell | Safe-Inferred |
|---|---|
| Language | GHC2021 |
RealDice.Convert
Description
This module re-exports all the conversion submodules. At time of writing, this includes converting to and from binary strings and strings suitable for CSV files
| Safe Haskell | Safe-Inferred |
|---|---|
| Language | GHC2021 |
RealDice.Convert
Description
This module re-exports all the conversion submodules. At time of writing, this includes converting to and from binary strings and strings suitable for CSV files